# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"plot_images": "00_visualize.ipynb",
         "multi_thread": "01_process.ipynb",
         "images_to_video": "03_utils.ipynb",
         "get_paths": "03_utils.ipynb"}

modules = ["visualize.py",
           "process.py",
           "utils.py"]

doc_url = "https://anhvth.github.io/avcv/"

git_url = "https://github.com/anhvth/avcv/tree/nbdev-convert/"

def custom_doc_links(name): return None
